@@ -48,6 +48,7 @@ def parse_command_line():
 	parser.add_option('--track-segments', action='store_true', default = False, help = 'Track IFO states. If given, kafka-server and input-topic are required. Default is False.')
 	parser.add_option('--ifo', action = 'append', help = 'IFOs to use. Can be given more than once.')
 	parser.add_option('--far-threshold', type = float, default = 2.315e-5, help = 'Set the FAR threshold for sending coincs. Used if data-source is fake-data. Default is 2 per day.')
+	parser.add_option('--f-max', type = float, default = 1600., help = 'Set the high frequency cut off for estimating the injection SNR.')
 	parser.add_option('--inj-rate', type = float, default = 20., help = 'Rate to send injection messages in the fake-data scheme. Default is 20 seconds.')
 	parser.add_option('--output-coinc', metavar = 'dir', default = 'output_files', help='the directory to output coinc files to')
 	opts, args = parser.parse_args()
@@ -66,6 +67,7 @@ class SendInjStream(object):
 		self.ifo_name = options.ifo
 		self.inj_rate = options.inj_rate
 		self.far_threshold = options.far_threshold
+		self.f_max = options.f_max
 		self.output_coinc = options.output_coinc
 		self.track_segments = options.track_segments
 		self.track_psd = options.track_psd
@@ -251,12 +253,13 @@ class SendInjStream(object):
 
 		return simtable
 
-	def segments_tracker(self, injection_time, max_retries = 10):
+	def segments_tracker(self, injection_time, max_retries = 100):
 		have_states = {ifo: False for ifo in self.ifo_name}
 
 		tries = 0
 		while not all(have_states.values()) and tries < max_retries:
 			for ifo in self.ifo_name:
+				logging.debug(f"Try {tries} to get state vector segments")
 				# either we have a state corresponding to this injection time
 				# or we have later states (for now assuming no state = IFO off)
 				have_states[ifo] = self.segments[ifo] and (injection_time in self.segments[ifo].keys() or next(reversed(self.segments[ifo])) > injection_time)
@@ -265,10 +268,9 @@ class SendInjStream(object):
 					# move on to check the next ifo
 					continue
 				else:
-					# sleep for the difference in time between the latest state
-					# and this injection so that the ll_dq job can catch up
-					if self.segments[ifo] and next(reversed(self.segments[ifo])) - injection_time > 0:
-						sleep(next(reversed(self.segments[ifo])) - injection_time)
+					# sleep for one second to allow the 
+					# state vector segments to catch up
+					sleep(1)
 
 					# pull and store new messages and try again
 					new_psd_msgs, new_segs = self.pull_dq_messages()
@@ -305,10 +307,14 @@ class SendInjStream(object):
 					value = json.loads(msg.value())
 					time = value['time']
 					state = value['data']
+					dict = statevectorsegments[ifo]
 					for t, s in zip(time, state):
+						if not t in dict:
+							dict[t] = []
 						# if we're getting segs from each job, there will be duplicates.
-						# append each state to a list for a given time
-						statevectorsegments[ifo].setdefault(t, []).append(s)
+						# dont store duplicate states from each job
+						if not s in dict[t]:
+							dict[t].append(s)
 	
 		return psds, statevectorsegments
 
@@ -373,7 +379,7 @@ class SendInjStream(object):
 		f_min = inj.f_lower
 		approximant = lalsimulation.GetApproximantFromString(str(inj.waveform))
 		sample_rate = 16384.0
-		f_max = 1600.
+		f_max = self.f_max
 	
 		h_plus, h_cross = lalsimulation.SimInspiralTD(
 			m1 = inj.mass1*lal.MSUN_SI,
