@@ -7,7 +7,7 @@ from ligo.gracedb.rest import GraceDb
 from ligo.gracedb.exceptions import HTTPError
 
 class GraceDbHelper(object):
-	def __init__(self, group='gracedb-playground'):
+	def __init__(self, group):
 		self.group = group
 		self.client = GraceDb(service_url=f'https://{self.group}.ligo.org/api/')
 
